@@ -22,7 +22,7 @@ package jacorb.idl;
 
 /**
  * @author Gerald Brose
- * @version $Id: Member.java,v 1.9 2000/09/08 14:51:19 brose Exp $
+ * @version $Id: Member.java,v 1.10 2000/12/04 16:16:31 brose Exp $
  *
  */
 
@@ -44,7 +44,7 @@ class Member
 	super(num);
     }
 
-    public void setPackage( String s, boolean propagate_into_included )
+    public void setPackage( String s)
     {
         s = parser.pack_replace(s);
 	if( pack_name.length() > 0 )
@@ -52,8 +52,8 @@ class Member
 	else
 	    pack_name = s;
 
-	type_spec.setPackage(s, propagate_into_included);
-	declarators.setPackage(s, propagate_into_included);
+	type_spec.setPackage(s);
+	declarators.setPackage(s);
     }
 
     public void setEnclosingSymbol( IdlSymbol s )
@@ -211,3 +211,11 @@ class Member
 
 
 
+
+
+
+
+
+
+
+
